#ifndef PATHS_H
#define PATHS_H

#include <QString>
#include <QList>
#include <QSize>

static const QString VERSION_NUMBER("1.0.3");
static const QString ICON_PATH("/opt/qdl/icons/");
#if (defined Q_WS_MAEMO_5) || (defined MAEMO4_OS)
static const QSize ICON_SIZE(36, 36);
#else
static const QSize ICON_SIZE(16, 16);
#endif
static const int MAX_CONCURRENT_TRANSFERS = 5;
static const int MAX_CONNECTIONS = 4;
static const QList<int> RATE_LIMITS = QList<int>() << 0 << 5000 << 10000 << 20000 << 50000 << 100000 << 250000 << 500000 << 750000;

#endif // PATHS_H
